## Project Description

This is the pip package for the empower-functions LLMs which offer GPT-4 level capatiblities for real-world "tool-using" use cases.

For more information, please visit the [Empower Functions](https://github.com/empower-ai/empower-functions) Github repo.